# pqfg — Piqued Forge

The lifelong developer platform from [Piqued AI](https://piqued-ai.com).

This is a namespace placeholder. The package is not yet functional.

## What is Piqued Forge?

Piqued Forge is the IDE and developer platform where the
Piqued Coding Manifesto becomes reality — from Heat through Hammer,
Quench, Polish, and Temper.

More information: [pqfg.dev](https://pqfg.dev)
